import { useState } from "react";
import { Link } from "wouter";
import { Button } from "@/components/ui/button";
import { Menu } from "lucide-react";
import { useWaitlistModal } from "@/WaitlistModalContext";
import {
  Drawer,
  DrawerTrigger,
  DrawerContent,
  DrawerHeader,
  DrawerTitle,
  DrawerFooter,
} from "@/components/ui/drawer";
import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import { 
  ChevronDown, 
  ChevronRight, 
  FileText, 
  Shield, 
  Building, 
  Sparkles, 
  FileImage, 
  Presentation, 
  Palette, 
  Heart,
  Bot,
  Database,
  LayoutTemplate,
  Brain,
  Zap,
  FileSpreadsheet,
  FolderKanban,
  Image,
  BarChart3,
  TrendingUp
} from "lucide-react";

export function NavBar() {
  const [platformOpen, setPlatformOpen] = useState(false);
  const [solutionsOpen, setSolutionsOpen] = useState(false);
  const [toolsOpen, setToolsOpen] = useState(false);
  const [servicesOpen, setServicesOpen] = useState(false);
  const { openWaitlistModal } = useWaitlistModal();
  
  return (
    <div className="sticky top-0 z-50 border-b bg-white shadow-sm">
      <div className="container mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex h-[4.5rem] items-center justify-between">
          {/* Mobile Menu Button - Left Side */}
          <div className="md:hidden flex items-center">
            <Button variant="ghost" size="icon" className="p-1 flex items-center justify-center" onClick={() => {
              document.getElementById('mobile-menu-modal')?.classList.remove('hidden');
            }}>
              <Menu style={{ width: '40px', height: '40px' }} />
            </Button>
            
            {/* Mobile Menu Modal */}
            <div id="mobile-menu-modal" className="hidden fixed inset-0 z-50">
              {/* Backdrop */}
              <div className="absolute inset-0 bg-white" onClick={() => {
                document.getElementById('mobile-menu-modal')?.classList.add('hidden');
              }}></div>
              
              {/* Menu Panel */}
              <div className="absolute inset-0 bg-white overflow-auto">
                <div className="flex justify-center pt-4">
                  <div className="w-16 h-1 bg-gray-200 rounded-full"></div>
                </div>
                
                <div className="p-6">
                  <div className="flex justify-between items-center mb-6">
                    <h3 className="text-xl font-semibold">Menu</h3>
                    <Button variant="ghost" size="icon" className="p-3" onClick={() => {
                      document.getElementById('mobile-menu-modal')?.classList.add('hidden');
                    }}>
                      <svg xmlns="http://www.w3.org/2000/svg" className="h-7 w-7" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round">
                        <line x1="18" y1="6" x2="6" y2="18"></line>
                        <line x1="6" y1="6" x2="18" y2="18"></line>
                      </svg>
                    </Button>
                  </div>
                  
                  <Accordion type="single" collapsible className="space-y-4 border-t border-b-0">
                    <AccordionItem value="platform" className="border-b">
                      <AccordionTrigger className="py-4 font-semibold">Platform</AccordionTrigger>
                      <AccordionContent>
                        <div className="space-y-4 py-2">
                          <Link href="/powerpoint" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <Presentation className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">Presentation Copilot</h2>
                              <p className="text-xs text-muted-foreground">Enhanced PowerPoint tools<br/>and presentation automation</p>
                            </div>
                          </Link>
                          
                          <Link href="/excel" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <FileSpreadsheet className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">Spreadsheet Copilot</h2>
                              <p className="text-xs text-muted-foreground">Easy data integration<br/>from Excel and Google Sheets</p>
                            </div>
                          </Link>
                          
                          <Link href="/ai-analyst" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <Brain className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">AI Analyst Builder</h2>
                              <p className="text-xs text-muted-foreground">Smart presentation insights<br/>and intelligent data analysis</p>
                            </div>
                          </Link>
                          
                          {/* <Link href="/asset-hub" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <FolderKanban className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">Web Manager</h2>
                              <p className="text-xs text-muted-foreground">Brand assets and compliance</p>
                            </div>
                          </Link> */}
                          
                          {/* Blog Post Section */}
                          <div className="mt-6 pt-4 border-t border-gray-200">
                            <Link 
                              href="/blog/ai-powered-presentations" 
                              className="block"
                              onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}
                            >
                              <div className="bg-gray-100 rounded-lg w-full h-24 mb-3 overflow-hidden border border-gray-200 relative">
                                <img 
                                  src="/blog-header.png" 
                                  alt="Meet the Deckcraft Product Family" 
                                  className="w-full h-full object-cover"
                                />
                                <div className="absolute inset-0 bg-gradient-to-t from-black/20 via-transparent to-transparent"></div>
                              </div>
                              <h2 className="text-sm font-medium">Meet the Deckcraft Product Family</h2>
                              <p className="text-xs text-muted-foreground mt-1">Learn how Deckcraft can help you save time and create top notch presentations</p>
                              <div className="flex items-center text-primary text-xs mt-2">
                                Read article <ChevronRight className="h-3 w-3 ml-1" />
                              </div>
                            </Link>
                          </div>
                        </div>
                      </AccordionContent>
                    </AccordionItem>
                    
                    <AccordionItem value="solutions" className="border-b">
                      <AccordionTrigger className="py-4 font-semibold">Solutions</AccordionTrigger>
                      <AccordionContent>
                        <div className="space-y-4 py-2">
                          <h3 className="text-xs font-semibold text-gray-500 uppercase mb-2">By Industry</h3>
                          
                          <Link href="/consulting" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <Sparkles className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">Consulting</h2>
                              <p className="text-xs text-muted-foreground">Powerful client presentations</p>
                            </div>
                          </Link>
                          
                          <Link href="/investment-banking" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <Shield className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">Investment Banking</h2>
                              <p className="text-xs text-muted-foreground">Professional pitch books</p>
                            </div>
                          </Link>
                          
                          <Link href="/venture-capital" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <Building className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">Venture Capital</h2>
                              <p className="text-xs text-muted-foreground">Streamline LP reporting</p>
                            </div>
                          </Link>

                        </div>
                        
                        {/* Featured Article Section */}
                        <div className="border-t border-gray-200 pt-4 mt-4">
                          <Link 
                            href="/blog/automated-agency" 
                            className="block"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}
                          >
                            <div className="bg-gray-100 rounded-lg w-full h-32 mb-3 overflow-hidden border border-gray-200 relative">
                              <img 
                                src="/connected-apps.png" 
                                alt="How we automated slides at our agency" 
                                className="w-full h-full object-cover"
                              />
                              <div className="absolute inset-0 bg-gradient-to-t from-black/20 via-transparent to-transparent"></div>
                            </div>
                            <h2 className="text-base font-medium text-gray-900 mb-1">How We Automated Our Agency</h2>
                            <p className="text-sm text-gray-500 mb-2">Learn how we built automated presentation workflows for our consultancy</p>
                            <div className="flex items-center text-primary text-sm">
                              Read article <ChevronRight className="h-3 w-3 ml-1" />
                            </div>
                          </Link>
                        </div>
                      </AccordionContent>
                    </AccordionItem>



                    <AccordionItem value="services" className="border-b">
                      <AccordionTrigger className="py-4 font-semibold">Services</AccordionTrigger>
                      <AccordionContent>
                        <div className="space-y-4 py-2">
                          <Link href="/custom-pitch-deck-creation" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <Presentation className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">Custom Pitch Deck Creation</h2>
                              <p className="text-xs text-muted-foreground">Professional pitch creation</p>
                            </div>
                          </Link>
                          
                          <Link href="/ai-infra-services" className="flex items-start gap-3 py-2 text-gray-700 hover:text-gray-900"
                            onClick={() => document.getElementById('mobile-menu-modal')?.classList.add('hidden')}>
                            <div className="flex h-8 w-8 shrink-0 items-center justify-center rounded-md bg-gray-100 mt-1">
                              <FileImage className="h-4 w-4 text-gray-600" />
                            </div>
                            <div>
                              <h2 className="text-base font-medium mb-0">AI Infra Setup</h2>
                              <p className="text-xs text-muted-foreground">Local AI deployment services</p>
                            </div>
                          </Link>
                        </div>
                      </AccordionContent>
                    </AccordionItem>
                  </Accordion>
                  
                  <div className="mt-8 space-y-3">
                    <Button 
                      variant="default" 
                      className="w-full py-6 text-base bg-primary hover:bg-primary/90"
                      asChild
                    >
                      <a href="https://app.deckcraft.ai" target="_blank" rel="noopener noreferrer">
                        Log In
                      </a>
                    </Button>
                    <Button 
                      variant="outline" 
                      className="w-full py-6 text-base"
                      onClick={() => {
                        document.getElementById('mobile-menu-modal')?.classList.add('hidden');
                        openWaitlistModal();
                      }}
                    >
                      Get Early Access
                    </Button>
                  </div>
                </div>
              </div>
            </div>
          </div>

          {/* Logo - Right side on mobile, left side on desktop */}
          <div className="md:order-first md:ml-8">
            <Link href="/" className="flex items-center">
              <svg width="204" height="47" viewBox="0 0 204 47" className="h-6 w-auto">
                <g id="Page-1" stroke="none" strokeWidth="1" fill="none" fillRule="evenodd">
                  <g id="Deckcraft-logo" transform="translate(0.222656, 0.113281)" fillRule="nonzero">
                    <path d="M131.265625,34.140625 C128.933594,36.429688 126.480469,37.332031 123.496094,37.332031 C117.648438,37.332031 112.78125,33.8125 112.78125,26.65625 C112.78125,19.5 117.648438,15.980469 123.496094,15.980469 C126.359375,15.980469 128.566406,16.800781 130.777344,18.96875 L127.628906,22.28125 C126.441406,21.214844 124.96875,20.683594 123.578125,20.683594 C120.222656,20.683594 117.769532,23.140625 117.769532,26.65625 C117.769532,30.5 120.386719,32.546875 123.496094,32.546875 C125.089844,32.546875 126.6875,32.097657 127.914063,30.867188 L131.265625,34.140625" id="Path" fill="#445DB4"/>
                    <path d="M153.742188,26.617188 C153.742188,30.460938 156.398438,32.75 159.710938,32.75 C167.5625,32.75 167.5625,20.523438 159.710938,20.523438 C156.398438,20.523438 153.742188,22.769531 153.742188,26.617188 Z M165.847656,16.554688 L170.632813,16.554688 L170.632813,36.714844 L165.929688,36.714844 L165.683594,33.773438 C164.539063,36.144531 161.386719,37.289063 159.140625,37.332031 C153.167969,37.371094 148.753906,33.691407 148.753906,26.617188 C148.753906,19.664063 153.375,16.023438 159.261719,16.0625 C161.960938,16.0625 164.539063,17.332031 165.683594,19.335938 L165.847656,16.554688" id="Shape" fill="#445DB4"/>
                    <path d="M147.167969,22.136719 C147.582032,20.539063 148.296875,19.199219 149.25,18.125 L149.34375,17.945313 C148.238282,16.839844 146.234375,16.023438 144.148438,16.023438 C142.105469,16.023438 140.019532,16.390625 138.464844,18.886719 L138.097656,16.554688 L133.472656,16.554688 L133.472656,36.714844 L138.464844,36.714844 L138.464844,26.082031 C138.464844,22.363281 140.878906,20.972657 143.496094,20.972657 C145.132813,20.972657 146.070313,21.421875 147.09375,22.28125 L147.167969,22.136719" id="Path" fill="#445DB4"/>
                    <path d="M201.132813,31.917969 C200.398438,32.285157 199.5,32.53125 198.722656,32.53125 C197.167969,32.53125 196.105469,31.589844 196.105469,29.667969 L196.105469,21.3125 L201.707032,21.3125 L201.707032,16.898438 L196.144532,16.898438 L196.144532,10.9375 L191.15625,11.46875 L191.15625,16.90625 L181.824219,16.910157 L181.824219,15.558594 C181.824219,13.105469 183.132813,11.960938 184.851563,11.960938 C185.875,11.960938 186.855469,12.328125 187.921875,13.023438 L189.757813,9.300781 C188.125,8.238281 186.285156,7.667969 184.523438,7.667969 C180.476563,7.667969 176.835938,10.160157 176.835938,15.558594 L176.835938,16.910157 L173.074219,16.910157 L173.074219,21.285157 L176.835938,21.285157 L176.835938,36.785157 L181.824219,36.785157 L181.824219,21.285157 L191.15625,21.285157 L191.15625,29.667969 C191.15625,34.699219 194.015625,37.03125 198.394532,37.03125 C199.867188,37.03125 201.71875,36.640625 203.222656,35.917969 L201.132813,31.917969" id="Path" fill="#445DB4"/>
                    <path d="M99.492188,46.613281 L0,46.613281 L0,10.375 C0,4.644531 4.644532,0 10.371094,0 L109.863282,0 L109.863282,36.242188 C109.863282,41.96875 105.21875,46.613281 99.492188,46.613281" id="Path" fill="#445DB4"/>
                    <path d="M55.328125,24.347657 C55.003906,21.746094 52.972656,20.449219 50.128906,20.449219 C47.445313,20.449219 45.25,21.746094 44.519532,24.347657 L55.328125,24.347657 Z M44.4375,28.453125 C44.761719,30.933594 46.917969,32.722657 50.414063,32.722657 C52.242188,32.722657 54.636719,32.03125 55.777344,30.851563 L58.945313,33.980469 C56.832032,36.175781 53.378906,37.234375 50.332032,37.234375 C43.421875,37.234375 39.316406,32.964844 39.316406,26.542969 C39.316406,20.449219 43.464844,16.058594 49.964844,16.058594 C56.671875,16.058594 60.855469,20.203125 60.085938,28.453125 L44.4375,28.453125" id="Shape" fill="#FFFFFF"/>
                    <path d="M81.09375,34.144531 C78.777344,36.417969 76.339844,37.3125 73.375,37.3125 C67.5625,37.3125 62.726563,33.820313 62.726563,26.707031 C62.726563,19.59375 67.5625,16.097657 73.375,16.097657 C76.21875,16.097657 78.414063,16.910157 80.605469,19.066407 L77.476563,22.359375 C76.300782,21.300781 74.835938,20.773438 73.457032,20.773438 C70.121094,20.773438 67.683594,23.210938 67.683594,26.707031 C67.683594,30.527344 70.285156,32.558594 73.375,32.558594 C74.957032,32.558594 76.542969,32.113281 77.761719,30.894531 L81.09375,34.144531" id="Path" fill="#FFFFFF"/>
                    <polyline id="Path" fill="#FFFFFF" points="88.386719 8.296875 88.386719 24.714844 95.132813 16.667969 101.066406 16.667969 101.066406 16.953125 92.898438 26.097657 102.203125 36.339844 102.203125 36.703125 96.230469 36.703125 88.386719 27.640625 88.386719 36.703125 83.429688 36.703125 83.429688 8.296875 88.386719 8.296875"/>
                    <path d="M22.226563,32.128907 L16.375,32.128907 L16.375,13.921875 L22.226563,13.921875 C28.402344,13.921875 31.003906,18.351563 31.128906,22.78125 C31.25,27.414063 28.6875,32.128907 22.226563,32.128907 Z M36.453125,22.257813 C36.453125,14.867188 30.460938,8.878907 23.070313,8.878907 L22.769532,8.878907 C22.597656,8.871094 22.425782,8.867188 22.25,8.867188 C18.753906,8.867188 14.566406,8.867188 11.074219,8.867188 L11.074219,37.3125 C14.566406,37.3125 18.753906,37.3125 22.25,37.3125 C31.640625,37.3125 36.078125,30.84375 36.449219,24.074219 L36.453125,24.074219 L36.453125,23.980469 C36.46875,23.601563 36.480469,23.222657 36.472656,22.847657 C36.46875,22.652344 36.464844,22.453125 36.453125,22.257813" id="Shape" fill="#FFFFFF"/>
                  </g>
                </g>
              </svg>
            </Link>
          </div>

          {/* Desktop Navigation */}
          <nav className="hidden md:flex items-center gap-6 ml-8">
            <DropdownMenu open={platformOpen} onOpenChange={setPlatformOpen}>
              <DropdownMenuTrigger className="flex items-center gap-1 font-display text-sm font-medium text-muted-foreground hover:text-foreground">
                Platform
                <ChevronDown className="h-4 w-4" />
              </DropdownMenuTrigger>
              <DropdownMenuContent align="start" className="w-[720px] rounded-xl">
                <div className="grid grid-cols-2 divide-x">
                  {/* Left Column - Platform options */}
                  <div className="py-4 px-4">                    
                    <div>
                      <Link 
                        href="/powerpoint" 
                        className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-1.5"
                        onClick={() => setPlatformOpen(false)}
                      >
                        <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                          <Presentation className="h-5 w-5 text-gray-600" />
                        </div>
                        <div>
                          <div className="font-['New_Grotesk'] text-base font-medium mb-0">Presentation Copilot</div>
                          <p className="text-sm text-muted-foreground">Enhanced PowerPoint tools<br/>and presentation automation</p>
                        </div>
                      </Link>
                      
                      <Link 
                        href="/excel" 
                        className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-1.5"
                        onClick={() => setPlatformOpen(false)}
                      >
                        <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                          <FileSpreadsheet className="h-5 w-5 text-gray-600" />
                        </div>
                        <div>
                          <div className="font-['New_Grotesk'] text-base font-medium mb-0">Spreadsheet Copilot</div>
                          <p className="text-sm text-muted-foreground">Easy data integration<br/>from Excel and Google Sheets</p>
                        </div>
                      </Link>
                      
                      <Link 
                        href="/ai-analyst" 
                        className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-1.5"
                        onClick={() => setPlatformOpen(false)}
                      >
                        <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                          <Brain className="h-5 w-5 text-gray-600" />
                        </div>
                        <div>
                          <div className="font-['New_Grotesk'] text-base font-medium mb-0">AI Analyst Builder</div>
                          <p className="text-sm text-muted-foreground">Smart presentation insights<br/>and intelligent data analysis</p>
                        </div>
                      </Link>
                      
                      {/* <Link 
                        href="/asset-hub" 
                        className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-1.5"
                        onClick={() => setPlatformOpen(false)}
                      >
                        <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                          <FolderKanban className="h-5 w-5 text-gray-600" />
                        </div>
                        <div>
                          <div className="font-['New_Grotesk'] text-base font-medium mb-0">Web Manager</div>
                          <p className="text-sm text-muted-foreground">Centralized resource hub</p>
                        </div>
                      </Link> */}
                    </div>
                  </div>
                  
                  {/* Right Column - Featured article */}
                  <div className="py-4 px-4">
                    <div className="mb-3">
                      
                    </div>
                    
                    <Link 
                      href="/blog/ai-powered-presentations" 
                      className="block"
                      onClick={() => setPlatformOpen(false)}
                    >
                      <div className="bg-gray-100 rounded-lg w-full h-36 mb-2 overflow-hidden border border-gray-200 relative">
                        <img 
                          src="/blog-header.png" 
                          alt="Meet the Deckcraft Product Family" 
                          className="w-full h-full object-cover"
                        />
                        <div className="absolute inset-0 bg-gradient-to-t from-black/20 via-transparent to-transparent"></div>
                      </div>
                      <h2 className="text-base font-medium">Meet the Deckcraft Product Family</h2>
                      <p className="text-sm text-muted-foreground mt-1">Learn how Deckcraft can help you save time and create top notch presentations</p>
                      <div className="flex items-center text-primary text-sm mt-2">
                        Read article <ChevronRight className="h-3 w-3 ml-1" />
                      </div>
                    </Link>
                  </div>
                </div>
              </DropdownMenuContent>
            </DropdownMenu>
            
            <DropdownMenu open={solutionsOpen} onOpenChange={setSolutionsOpen}>
              <DropdownMenuTrigger className="flex items-center gap-1 font-display text-sm font-medium text-muted-foreground hover:text-foreground">
                Solutions
                <ChevronDown className="h-4 w-4" />
              </DropdownMenuTrigger>
              <DropdownMenuContent align="start" className="w-[720px] rounded-xl">
                <div className="grid grid-cols-2 divide-x">
                  {/* Left Column - Solutions/Tools */}
                  <div className="py-4 px-4">                    
                    <div>
                      <Link 
                        href="/consulting" 
                        className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-1.5"
                        onClick={() => setSolutionsOpen(false)}
                      >
                        <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                          <Sparkles className="h-5 w-5 text-gray-600" />
                        </div>
                        <div>
                          <div className="font-['New_Grotesk'] text-base font-medium mb-0">Consulting</div>
                          <p className="text-sm text-muted-foreground">Powerful client presentations<br/>and proposal automation</p>
                        </div>
                      </Link>
                      
                      <Link 
                        href="/investment-banking" 
                        className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-1.5"
                        onClick={() => setSolutionsOpen(false)}
                      >
                        <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                          <Shield className="h-5 w-5 text-gray-600" />
                        </div>
                        <div>
                          <div className="font-['New_Grotesk'] text-base font-medium mb-0">Investment Banking</div>
                          <p className="text-sm text-muted-foreground">Professional pitch books<br/>and transaction materials</p>
                        </div>
                      </Link>
                      
                      <Link 
                        href="/venture-capital" 
                        className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-1.5"
                        onClick={() => setSolutionsOpen(false)}
                      >
                        <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                          <Building className="h-5 w-5 text-gray-600" />
                        </div>
                        <div>
                          <div className="font-['New_Grotesk'] text-base font-medium mb-0">Venture Capital</div>
                          <p className="text-sm text-muted-foreground">Streamline LP reporting<br/>and portfolio communications</p>
                        </div>
                      </Link>
                    </div>
                  </div>
                  
                  {/* Right Column - Featured article */}
                  <div className="py-4 px-4">
                    <div className="mb-3">
                      
                    </div>
                    
                    <Link 
                      href="/blog/automated-agency" 
                      className="block"
                      onClick={() => setSolutionsOpen(false)}
                    >
                      <div className="bg-gray-100 rounded-lg w-full h-36 mb-2 overflow-hidden border border-gray-200 relative">
                        <img 
                          src="/connected-apps.png" 
                          alt="How we automated presentation making at our consultancy" 
                          className="w-full h-full object-cover"
                        />
                        <div className="absolute inset-0 bg-gradient-to-t from-black/20 via-transparent to-transparent"></div>
                      </div>
                      <h2 className="text-base font-medium">How we automated our agency</h2>
                      <p className="text-sm text-muted-foreground mt-1">A breakdown of how our consultancy automated its' presentation workflows</p>
                      <div className="flex items-center text-primary text-sm mt-2">
                        Read article <ChevronRight className="h-3 w-3 ml-1" />
                      </div>
                    </Link>
                  </div>
                </div>
              </DropdownMenuContent>
            </DropdownMenu>





            {/* <DropdownMenu open={servicesOpen} onOpenChange={setServicesOpen}>
              <DropdownMenuTrigger className="flex items-center gap-1 font-display text-sm font-medium text-muted-foreground hover:text-foreground">
                Services
                <ChevronDown className="h-4 w-4" />
              </DropdownMenuTrigger>
              <DropdownMenuContent align="start" className="w-[450px] rounded-xl">
                <div className="p-4">                  
                  <div>
                    <Link 
                      href="/custom-pitch-deck-creation" 
                      className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-2.5"
                      onClick={() => setServicesOpen(false)}
                    >
                      <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                        <Presentation className="h-5 w-5 text-gray-600" />
                      </div>
                      <div>
                        <div className="font-['New_Grotesk'] text-base font-medium mb-0">Custom Pitch Deck Creation</div>
                        <p className="text-sm text-muted-foreground">Professional pitch creation</p>
                      </div>
                    </Link>
                    
                    <Link 
                      href="/ai-infra-services" 
                      className="flex items-center gap-3 p-2 rounded-md hover:bg-gray-50 transition-colors mb-2.5"
                      onClick={() => setServicesOpen(false)}
                    >
                      <div className="flex h-10 w-10 shrink-0 items-center justify-center rounded-md bg-gray-100">
                        <FileImage className="h-5 w-5 text-gray-600" />
                      </div>
                      <div>
                        <div className="font-['New_Grotesk'] text-base font-medium mb-0">AI Infra Setup</div>
                        <p className="text-sm text-muted-foreground">Local AI deployment services</p>
                      </div>
                    </Link>
                    

                  </div>
                </div>
              </DropdownMenuContent>
            </DropdownMenu> */}

            {/* About link hidden per request */}
          </nav>

          {/* Desktop Buttons */}
          <div className="hidden md:flex items-center ml-auto">
            <div className="flex items-end gap-3">
              <Button 
                variant="default" 
                className="font-display bg-primary hover:bg-primary/90"
                asChild
              >
                <a href="https://app.deckcraft.ai" target="_blank" rel="noopener noreferrer">
                  Log In
                </a>
              </Button>
              <Button 
                variant="outline" 
                className="font-display"
                onClick={openWaitlistModal}
              >
                Get Early Access
              </Button>
            </div>
          </div>
          
          {/* Waitlist Modal now handled by WaitlistModalProvider */}
        </div>
      </div>
    </div>
  );
}